% --- Source file: SAMC.fun.Rd ---
\name{SAMC.fun}
\alias{SAMC.fun}
\title{SAMC algorithm}
\description{
  This function is to run the SAMC algorithm with user defined subregion definition.  
}
\usage{
SAMC.fun(data.input, n.iter, partition.vec, prop.change, theta.start, 
      gain.factor.t0, fun.test.statistic, fun.proposal, ...)
}
\arguments{
  \item{data.input}{The input data, which can be any data object, e.g. data frame, list, etc., as long as it
     is compatible with the two user provided functions \code{fun.test.statistic} and \code{fun.proposal}. }
  \item{n.iter}{The number of iterations}
  \item{partition.vec}{A vector of length m of cut points at the domain of the test statistic. The first subregion is 
      defined as [\code{partition.vec[1]}, \code{partition.vec[2]}], the second subregion is [\code{partition.vec[2]}, \code{partition.vec[3]}], ...,
      with final subregion being [\code{partition.vec[m]}, \eqn{\infty}{\\Inf}). Usually \code{partition.vec[1]} is the minimum value
      of the test statistic (e.g. 0), and \code{partition.vec[m]} can be set as the observed test
      statistic whose p-value is to be estimated. }
  \item{prop.change}{The percentage of data to be updated by \code{fun.proposal} in each iteration.}
  \item{theta.start}{theta.start}
  \item{gain.factor.t0}{This is used for defining the gain factor sequence.}
  \item{fun.test.statistic}{A function written by the user to calculate and return the test statistic based on
         \code{data.input}. It has the following format: \code{fun.test.statistic(data.input, ...)}. 
         See the example function \code{t.test.statistic}.}
  \item{fun.proposal}{A function written by the user to update the input data and return the updated data.
        It should be in the following format: \code{fun.proposal(data.input, prop.change, ...)}.
        See the example function \code{proposal.permute.vector}.}
  \item{...}{Other arguments for \code{fun.test.statistic} and/or \code{fun.proposal}}
}
\value{
  A list with two components \code{hist.mat} and \code{p.value} (see \code{\link{SAMC.adapt}}). 
 }
\details{
  This function estimates the tail probability
   \deqn{P(\lambda(x) \geq partition.vec[m])}{P(lambda(x) >= partition.vec[m])}
} % END: details
\references{ 
Yu K, Liang F, Ciampa J, Chatterjee N. Efficient p-value evaluation for resampling-based tests (Submitted manuscript).
 }
\author{Kai Yu }
\seealso{ \code{\link{SAMC.adapt}}, \code{\link{t.test.statistic}}, \code{\link{proposal.permute.vector}} }
%\examples{
%}

\keyword{ htest } 

